# -*- coding: utf-8 -*-
from threatbutt import ThreatButt


def test_ioc():
    tb = ThreatButt()
    response = tb.clown_strike_ioc('127.0.0.1')
    assert len(response)


def test_md5():
    tb = ThreatButt()
    response = tb.bespoke_md5('d41d8cd98f00b204e9800998ecf8427e')
    assert len(response)



# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup


setup(
    name='threatbutt',
    version='1.0.1',
    provides=['threatbutt'],
    author='c0wl',
    url='https://github.com/ivanlei/threatbutt',
    setup_requires='setuptools',
    license='Apache License v 2.0',
    author_email='ivanlei@yelp.com',
    description='Defense in derpth - maximum protection from hacker threats like 4Chan and Reddit.',
    packages=find_packages(),
    install_requires=[
        'argparse==1.3.0',
        'requests==2.6.2'
    ],
    entry_points={
        'console_scripts': [
            'threatbutt=threatbutt.threatbutt:main',
        ],
    },
)
